ML Environment Doctor - Diagnostic Report

# 🔍 ML Environment Doctor

Diagnostic Report - Generated on 2026-01-31 23:40:29

Version 0.1.2

### Total Checks

7

### Passed

7

### Warnings

0

### Critical Issues

0

Issue | Status | Severity | Fix | Details
--- | --- | --- | --- | ---
PyTorch CUDA | PASS - CUDA 12.1 (1 GPU(s)) | INFO | - | PyTorch 2.4.0+cu121, Device: NVIDIA GeForce RTX 3050 Laptop GPU
NVIDIA GPU Driver | PASS - CUDA 13.0 | INFO | - | CUDA Version: 13.0
transformers | PASS - 4.57.6 | INFO | - | -
peft | PASS - 0.18.1 | INFO | - | -
trl | PASS - 0.27.0 | INFO | - | -
datasets | PASS - 4.5.0 | INFO | - | -
accelerate | PASS - 1.12.0 | INFO | - | -